0.9.9 API documentation: scalar_relational.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

ext/scalar_relational.hpp
Go to the documentation of this file.
1
15 #pragma once
16
17 // Dependencies
18 #include "../detail/qualifier.hpp"
19
20 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
21 # pragma message("GLM: GLM_EXT_scalar_relational extension included")
22 #endif
23
24 namespace glm
25 {
30 template<typename genType>
31 GLM_FUNC_DECL GLM_CONSTEXPR bool equal(genType const& x, genType const& y, genType const& epsilon);
32
37 template<typename genType>
38 GLM_FUNC_DECL GLM_CONSTEXPR bool notEqual(genType const& x, genType const& y, genType const& epsilon);
39
48 template<typename genType>
49 GLM_FUNC_DECL GLM_CONSTEXPR bool equal(genType const& x, genType const& y, int ULPs);
50
59 template<typename genType>
60 GLM_FUNC_DECL GLM_CONSTEXPR bool notEqual(genType const& x, genType const& y, int ULPs);
61
63 }//namespace glm
64
65 #include "scalar_relational.inl"
glm::notEqual
GLM_FUNC_DECL GLM_CONSTEXPR vec< C, bool, Q > notEqual(mat< C, R, T, Q > const &x, mat< C, R, T, Q > const &y)
Perform a component-wise not-equal-to comparison of two matrices.
glm::equal
GLM_FUNC_DECL GLM_CONSTEXPR vec< C, bool, Q > equal(mat< C, R, T, Q > const &x, mat< C, R, T, Q > const &y)
Perform a component-wise equal-to comparison of two matrices.
glm::epsilon
GLM_FUNC_DECL GLM_CONSTEXPR genType epsilon()
Return the epsilon constant for floating point types.
glm
Definition: common.hpp:20